rcvd = add_state(_('received'),             'Application', initial=True)
schd = add_state(_('interview scheduling'), 'Application')
plan = add_state(_('interview planned'),    'Application')
deci = add_state(_('decision pending'),     'Application')
nrej = add_state(_('notify reject'),        'Application')
nacp = add_state(_('notiy accept'),         'Application')
recp = add_state(_('recruitment pending'),  'Application')
recd = add_state(_('recruited'),            'Application')
rejt = add_state(_('rejected'),             'Application')
canc = add_state(_('canceled'),             'Application')

add_transition(_('cancel application'),  'Application', (rcvd, schd, plan, deci, nrej, nacp, recp),  canc)
add_transition(_('schedule interview'),  'Application', (rcvd, deci), schd)
add_transition(_('reject application'),  'Application', (rcvd, deci), nrej)
add_transition(_('accept application'),  'Application', (deci,), nacp)
add_transition(_('send negative answer'),'Application', (nrej,), rejt)
add_transition(_('accept interview'),    'Application', (schd,), plan)
add_transition(_('send positive answer'),'Application', (nacp,), recp)
add_transition(_('recruited accepted'),  'Application', (recp,), recd)
add_transition(_('interview done'),      'Application', (plan,), deci)

checkpoint()
